@@ -11,7 +11,7 @@ from subprocess import CalledProcessError
 try:
     from pathlib import Path
 except ImportError:
-    from pathlib2 import Path
+    from pipenv.vendor.pathlib2 import Path
 
 try:
     from shutil import get_terminal_size
@@ -56,7 +56,6 @@ else:
     default_home = os.path.join(
         os.environ.get('XDG_DATA_HOME', '~/.local/share'), 'virtualenvs')
 
-
 def get_workon_home():
     return expandpath(os.environ.get('WORKON_HOME', default_home))
 
@@ -185,7 +184,8 @@ def fork_bash(env, cwd):
 
 def fork_cmder(env, cwd):
     shell_cmd = ['cmd']
-    cmderrc_path = r'%CMDER_ROOT%\vendor\init.bat'
+    escaped_cmder_root = os.environ['CMDER_ROOT'].replace(' ', '^ ')
+    cmderrc_path = r'{0}\vendor\init.bat'.format(escaped_cmder_root)
     if expandpath(cmderrc_path).exists():
         shell_cmd += ['/k', cmderrc_path]
     if cwd:
@@ -216,6 +216,8 @@ def shell(env, cwd=None):
             inve(env, shell, '-c', shell_check)
         except CalledProcessError:
             return
+    if shell_name in ('Cmder', 'cmd'):
+        os.environ['PROMPT'] = '({0}) {1}'.format(env, os.environ['PROMPT'])
     if shell_name == 'bash':
         fork_bash(env, cwd)
     elif shell_name == 'Cmder':
@@ -639,6 +641,7 @@ def restore_cmd(argv):
 
     env = argv[0]
     path = get_workon_home() / env
+    path = workon_home / env
     py = path / env_bin_dir / ('python.exe' if windows else 'python')
     exact_py = py.resolve().name
 
